#version 110

varying vec2 windowCoord;
varying float wOffset;
varying float wZfactor;

uniform int lightNumber;
uniform sampler2D buffer1;
uniform sampler2D buffer2;
uniform sampler2D buffer3;
uniform sampler2DShadow depthMap;

vec4 element1;
vec4 element2;
vec4 color;
vec3 normal;
vec4 position;
float depth;
float shade;
float shininess;
float emission;

void addLightToFragment (void)
{
	vec3 light = normalize(gl_LightSource[0].position.xyz);
	vec3 half = normalize(light+normalize(-position.xyz));
	
	//gl_FragColor = color*gl_LightSource[0].ambient;
	
	float angle = dot(light, normal);
	
	angle = clamp(angle,0.0,1.0);
	
	gl_FragColor = shade*angle*color*gl_LightSource[0].diffuse;
	
	angle = dot(half, normal);
	
	angle = clamp(angle,0.0,1.0);
	
	gl_FragColor += shade*pow(angle,shininess)*0.5*gl_LightSource[0].specular;
}

void main (void)
{
	element2 = texture2D(buffer2, gl_TexCoord[0].xy);
	
	if (element2.xyz == vec3(0))
		discard;
		
	shininess = length(element2.xyz);
	normal = normalize(element2.xyz);
		
	element1 = texture2D(buffer1, gl_TexCoord[0].xy);
	emission = element1.a;
	color = vec4(element1.rgb,0);

	position = texture2D(buffer3, gl_TexCoord[0].xy);
	
	vec4 texturePosition = gl_TextureMatrix[2] * (gl_ModelViewMatrixInverse * position);
	shade = shadow2DProj(depthMap, texturePosition).x;
	
	addLightToFragment();
	
}


